@@ -107,16 +107,16 @@ typedef struct ls_RegConst {
 // This is needed because some flags are not defined on all platforms. So we
 // still export the constants, but they will be all 0, and hence not do anything.
 #ifdef _WIN32
-// check compatibility: Windows virtual terminal processing was added in 2015,
-// some older compiler suites don't have the proper headers.
-#ifndef ENABLE_VIRTUAL_TERMINAL_INPUT
-#error Virtual terminal macros are undefined (eg. ENABLE_VIRTUAL_TERMINAL_INPUT). Update the toolchain or revert to Luasystem < 0.4
-#endif
-#define CHECK_WIN_FLAG_OR_ZERO(flag) flag
-#define CHECK_NIX_FLAG_OR_ZERO(flag) 0
+ // check compatibility: Windows virtual terminal processing was added in 2015,
+ // some older compiler suites don't have the proper headers.
+ #ifndef ENABLE_VIRTUAL_TERMINAL_INPUT
+  #error Virtual terminal macros are undefined (eg. ENABLE_VIRTUAL_TERMINAL_INPUT). Update the toolchain or revert to Luasystem < 0.4
+ #endif
+ #define CHECK_WIN_FLAG_OR_ZERO(flag) flag
+ #define CHECK_NIX_FLAG_OR_ZERO(flag) 0
 #else
-#define CHECK_WIN_FLAG_OR_ZERO(flag) 0
-#define CHECK_NIX_FLAG_OR_ZERO(flag) flag
+ #define CHECK_WIN_FLAG_OR_ZERO(flag) 0
+ #define CHECK_NIX_FLAG_OR_ZERO(flag) flag
 #endif
 
 // Export Windows constants to Lua
@@ -166,8 +166,8 @@ static const struct ls_RegConst nix_console_i_flags[] = {
     {"I_INLCR", CHECK_NIX_FLAG_OR_ZERO(INLCR)},
     {"I_IGNCR", CHECK_NIX_FLAG_OR_ZERO(IGNCR)},
     {"I_ICRNL", CHECK_NIX_FLAG_OR_ZERO(ICRNL)},
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
-    {"I_IUCLC", CHECK_NIX_FLAG_OR_ZERO(IUCLC)}, // Might not be available on all systems
+#ifdef IUCLC
+    {"I_IUCLC", CHECK_NIX_FLAG_OR_ZERO(IUCLC)},
 #else
     {"I_IUCLC", 0},
 #endif
@@ -181,8 +181,8 @@ static const struct ls_RegConst nix_console_i_flags[] = {
 static const struct ls_RegConst nix_console_o_flags[] = {
     // Output flags (c_oflag)
     {"O_OPOST", CHECK_NIX_FLAG_OR_ZERO(OPOST)},
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
-    {"O_OLCUC", CHECK_NIX_FLAG_OR_ZERO(OLCUC)}, // Might not be available on all systems
+#ifdef OLCUC
+    {"O_OLCUC", CHECK_NIX_FLAG_OR_ZERO(OLCUC)},
 #else
     {"O_OLCUC", 0},
 #endif
@@ -190,25 +190,44 @@ static const struct ls_RegConst nix_console_o_flags[] = {
     {"O_OCRNL", CHECK_NIX_FLAG_OR_ZERO(OCRNL)},
     {"O_ONOCR", CHECK_NIX_FLAG_OR_ZERO(ONOCR)},
     {"O_ONLRET", CHECK_NIX_FLAG_OR_ZERO(ONLRET)},
-#ifndef __FreeBSD__
+#ifdef OFILL
     {"O_OFILL", CHECK_NIX_FLAG_OR_ZERO(OFILL)},
-    {"O_OFDEL", CHECK_NIX_FLAG_OR_ZERO(OFDEL)},
-    {"O_NLDLY", CHECK_NIX_FLAG_OR_ZERO(NLDLY)},
-    {"O_CRDLY", CHECK_NIX_FLAG_OR_ZERO(CRDLY)},
 #else
     {"O_OFILL", 0},
+#endif
+#ifdef OFDEL
+    {"O_OFDEL", CHECK_NIX_FLAG_OR_ZERO(OFDEL)},
+#else
     {"O_OFDEL", 0},
+#endif
+#ifdef NLDLY
+    {"O_NLDLY", CHECK_NIX_FLAG_OR_ZERO(NLDLY)},
+#else
     {"O_NLDLY", 0},
+#endif
+#ifdef CRDLY
+    {"O_CRDLY", CHECK_NIX_FLAG_OR_ZERO(CRDLY)},
+#else
     {"O_CRDLY", 0},
 #endif
+#ifdef TABDLY
     {"O_TABDLY", CHECK_NIX_FLAG_OR_ZERO(TABDLY)},
-#ifndef __FreeBSD__
+#else
+    {"O_TABDLY", 0},
+#endif
+#ifdef BSDLY
     {"O_BSDLY", CHECK_NIX_FLAG_OR_ZERO(BSDLY)},
-    {"O_VTDLY", CHECK_NIX_FLAG_OR_ZERO(VTDLY)},
-    {"O_FFDLY", CHECK_NIX_FLAG_OR_ZERO(FFDLY)},
 #else
     {"O_BSDLY", 0},
+#endif
+#ifdef VTDLY
+    {"O_VTDLY", CHECK_NIX_FLAG_OR_ZERO(VTDLY)},
+#else
     {"O_VTDLY", 0},
+#endif
+#ifdef FFDLY
+    {"O_FFDLY", CHECK_NIX_FLAG_OR_ZERO(FFDLY)},
+#else
     {"O_FFDLY", 0},
 #endif
     {NULL, 0}
@@ -218,8 +237,8 @@ static const struct ls_RegConst nix_console_l_flags[] = {
     // Local flags (c_lflag)
     {"L_ISIG", CHECK_NIX_FLAG_OR_ZERO(ISIG)},
     {"L_ICANON", CHECK_NIX_FLAG_OR_ZERO(ICANON)},
-#if !defined(__APPLE__) && !defined(__FreeBSD__)
-    {"L_XCASE", CHECK_NIX_FLAG_OR_ZERO(XCASE)}, // Might not be available on all systems
+#ifdef XCASE
+    {"L_XCASE", CHECK_NIX_FLAG_OR_ZERO(XCASE)},
 #else
     {"L_XCASE", 0},
 #endif
@@ -229,9 +248,9 @@ static const struct ls_RegConst nix_console_l_flags[] = {
     {"L_ECHONL", CHECK_NIX_FLAG_OR_ZERO(ECHONL)},
     {"L_NOFLSH", CHECK_NIX_FLAG_OR_ZERO(NOFLSH)},
     {"L_TOSTOP", CHECK_NIX_FLAG_OR_ZERO(TOSTOP)},
-    {"L_ECHOCTL", CHECK_NIX_FLAG_OR_ZERO(ECHOCTL)}, // Might not be available on all systems
-    {"L_ECHOPRT", CHECK_NIX_FLAG_OR_ZERO(ECHOPRT)}, // Might not be available on all systems
-    {"L_ECHOKE", CHECK_NIX_FLAG_OR_ZERO(ECHOKE)}, // Might not be available on all systems
+    {"L_ECHOCTL", CHECK_NIX_FLAG_OR_ZERO(ECHOCTL)},
+    {"L_ECHOPRT", CHECK_NIX_FLAG_OR_ZERO(ECHOPRT)},
+    {"L_ECHOKE", CHECK_NIX_FLAG_OR_ZERO(ECHOKE)},
     {"L_FLUSHO", CHECK_NIX_FLAG_OR_ZERO(FLUSHO)},
     {"L_PENDIN", CHECK_NIX_FLAG_OR_ZERO(PENDIN)},
     {"L_IEXTEN", CHECK_NIX_FLAG_OR_ZERO(IEXTEN)},
@@ -585,7 +604,7 @@ static int lst_tcsetattr(lua_State *L)
 {
 #ifndef _WIN32
     struct termios t;
-    int r, i;
+    int r;
     int fd = get_console_handle(L);     // first is the console handle
     int act = luaL_checkinteger(L, 2);  // second is the action to take
 
@@ -949,30 +968,47 @@ int utf8_to_wchar(const char *utf8, size_t len, mk_wchar_t *codepoint) {
 /***
 Get the width of a utf8 character for terminal display.
 @function utf8cwidth
-@tparam string utf8_char the utf8 character to check, only the width of the first character will be returned
+@tparam string|int utf8_char the utf8 character, or unicode codepoint, to check, only the width of the first character will be returned
 @treturn[1] int the display width in columns of the first character in the string (0 for an empty string)
 @treturn[2] nil
 @treturn[2] string error message
 */
 int lst_utf8cwidth(lua_State *L) {
-    const char *utf8_char;
-    size_t utf8_len;
-    utf8_char = luaL_checklstring(L, 1, &utf8_len);
     int width = 0;
-
     mk_wchar_t wc;
 
-    if (utf8_len == 0) {
-        lua_pushinteger(L, 0);
-        return 1;
-    }
+    if (lua_type(L, 1) == LUA_TSTRING) {
+        // Handle UTF8 as string input
+        const char *utf8_char;
+        size_t utf8_len;
+        utf8_char = luaL_checklstring(L, 1, &utf8_len);
 
-    // Convert the UTF-8 string to a wide character
-    int bytes_processed = utf8_to_wchar(utf8_char, utf8_len, &wc);
-    if (bytes_processed == -1) {
-        lua_pushnil(L);
-        lua_pushstring(L, "Invalid UTF-8 character");
-        return 2;
+        if (utf8_len == 0) {
+            lua_pushinteger(L, 0);
+            return 1;
+        }
+
+        // Convert the UTF-8 string to a wide character
+        int bytes_processed = utf8_to_wchar(utf8_char, utf8_len, &wc);
+        if (bytes_processed == -1) {
+            lua_pushnil(L);
+            lua_pushstring(L, "Invalid UTF-8 character");
+            return 2;
+        }
+
+    } else if (lua_type(L, 1) == LUA_TNUMBER) {
+        // Handle codepoint input
+        int codepoint = luaL_checkinteger(L, 1);
+
+        if (codepoint < 0 || codepoint > 0x10FFFF) {
+            lua_pushnil(L);
+            lua_pushstring(L, "Invalid Unicode codepoint");
+            return 2;
+        }
+        wc = (mk_wchar_t)codepoint;
+
+    } else {
+        return luaL_argerror(L, 1, "Expected UTF-8-string or codepoint-integer as first argument");
     }
 
     // Get the width of the wide character
